aboutsummaryrefslogtreecommitdiff
path: root/lib/smtp.c
diff options
context:
space:
mode:
Diffstat (limited to 'lib/smtp.c')
-rw-r--r--lib/smtp.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/smtp.c b/lib/smtp.c
index 120afaf80..5675ff4ee 100644
--- a/lib/smtp.c
+++ b/lib/smtp.c
@@ -571,8 +571,8 @@ static CURLcode smtp_perform_command(struct connectdata *conn)
/* Send the VRFY command */
result = Curl_pp_sendf(&conn->proto.smtpc.pp, "VRFY %s", smtp->rcpt->data);
else
- /* Send the NOOP command */
- result = Curl_pp_sendf(&conn->proto.smtpc.pp, "%s", "NOOP");
+ /* Send the HELP command */
+ result = Curl_pp_sendf(&conn->proto.smtpc.pp, "%s", "HELP");
if(!result)
state(conn, SMTP_COMMAND);